@@ -1,3 +1,4 @@
+import math
 import time
 from functools import wraps
 from sqlalchemy import desc
@@ -34,4 +35,5 @@ class RecordsPage:
         self.num_records = num_records
         self.page_records = page_records
         self.per_page = per_page
-        self.current_page = current_page
\ No newline at end of file
+        self.current_page = current_page
+        self.num_pages = math.ceil(num_records / per_page) if per_page else None
